@@ -1,17 +1,14 @@
-import asyncio
-
 import click
 
 from taskforge.commands.cli import cli
-from taskforge.commands.utils import coro, inject_client, spinner
+from taskforge.commands.utils import inject_client, spinner
 from taskforge.state import State
 
 
 @cli.command(aliases=["c", "done", "d"])
 @click.argument("task-ids", nargs=-1)
-@coro
 @inject_client
-async def complete(
+def complete(
     task_ids,
     client,
 ):
@@ -20,14 +17,10 @@ async def complete(
     """
     with spinner("Completing tasks..."):
         if not task_ids:
-            top = await client.tasks.next(State.current_context)
+            top = client.tasks.next(State.current_context)
             task_ids = [top["id"]]
 
-        await asyncio.gather(
-            *map(
-                client.tasks.complete,
-                task_ids,
-            )
-        )
+        for task in task_ids:
+            client.tasks.complete(task)
 
     click.echo("DONE!")
