@@ -1,7 +1,7 @@
 import click
 
 from taskforge.commands.cli import cli
-from taskforge.commands.utils import coro, inject_client
+from taskforge.commands.utils import inject_client
 from taskforge.printing import print_json
 from taskforge.state import State
 
@@ -10,9 +10,8 @@ from taskforge.state import State
 @click.option("-t", "--title-only", "title_only", is_flag=True, default=False)
 @click.option("-i", "--id-only", "id_only", is_flag=True, default=False)
 @click.option("-j", "--json", "as_json", is_flag=True, default=False)
-@coro
 @inject_client
-async def next(
+def next(
     title_only,
     id_only,
     as_json,
@@ -24,7 +23,7 @@ async def next(
     This is calculated by Taskforge according to your strategy. The default strategy is
     highest priority first, oldest task first.
     """
-    task = await client.tasks.next(context=State.current_context)
+    task = client.tasks.next(context=State.current_context)
     if title_only:
         print(task["title"])
     elif id_only:
